@@ -14,8 +14,9 @@ def quit(app):
 def dashport(stdscr):
     app = Dashport(stdscr, color_default=176)
     app.add_control("q", quit, case_sensitive=False)
-    app.split_screen_three_vert(border=True, long_side="right",
-                                long_side_width=20)
+    app.layout("three_panels_vert",
+               border=True, long_side="right",
+               long_side_width=20)
     app.print("panel 0", x=1, y=1, panel="layout.0")
     app.print(f"Rows: {app.panel_dimensions[0][0]}", x=5, y=2,
               panel="layout.0")
